@@ -131,7 +131,7 @@ MvObsSet :: _init( const  char *aName )
      cout << "MvObsSet::_init - PrepBUFR support NOT available!!!!" << endl;
 #endif
    }
-   cout << "in MvObsSet::_init(" << aName << ")" << endl;
+   cout << "MvObsSet::_init(" << aName << ")" << endl;
 }
 //____________________________________________________________________ setSubsetMax
 void
@@ -358,7 +358,7 @@ MvObsSet::prepBufrFile()
 {
    if( isPrepBufrFile_ )
    {
-      cout << "in MvObsSet::prepBufrFile()" << endl;
+      cout << "MvObsSet::prepBufrFile()" << endl;
 #ifdef METVIEW
 //      marslog( LOG_INFO, "BUFR file contains BUFR tables, processing..." );
 #endif
