@@ -137,10 +137,31 @@ void FortranMagics::popen()
 	MagLog::userInfo() << "------------------------------------------------------------------\n";
    }
   // actions_.push(&FortranMagics::legend);
-   actions_.push(&FortranMagics::subpage);	
-   actions_.push(&FortranMagics::page);	
-   actions_.push(&FortranMagics::superpage);	
-   actions_.push(&FortranMagics::drivers);	
+   actions_.push(&FortranMagics::subpage);
+   actions_.push(&FortranMagics::page);
+   actions_.push(&FortranMagics::superpage);
+   actions_.push(&FortranMagics::drivers);
+}
+
+/*!
+ the Magics log messages are not broadcast until the next log event - therefore, the
+ last log message will not be broadcast. We fix that by flushing the message streams
+ - we only need to do one of them, and all will be flushed behind the scenes.
+*/
+inline void printFooter()
+{
+//	MagLog::info().flush();
+
+	if(getEnvVariable("MAGPLUS_QUIET").empty() )
+	{
+		MagLog::userInfo() << "------------------------------------------------------------------\n";
+		MagLog::userInfo() << "    COMPLETED\n";
+		MagLog::userInfo() << "\n";
+		MagLog::userInfo() << "    Any problems or suggestions? Please contact us at\n";
+		MagLog::userInfo() << "                   magics@ecmwf.int\n";
+		MagLog::userInfo() << "------------------------------------------------------------------\n";
+	}
+//	MagLog::userInfo().flush();
 }
 
 /*! \brief Main dispatch method
@@ -149,58 +170,42 @@ void FortranMagics::popen()
 */
 void FortranMagics::pclose()
 {
-	if (!empty_) {
-		finish();
-		dispatch();
-	}
+  if (!empty_) {
+     finish();
+     dispatch();
+  }
 
-	/***   Start clean-up  ***/
-	drivers_->dispatch(root_->close());
-	if ( root_ && drivers_)
-	{
-		//root_->execute();
-		drivers_->closeDrivers();
-		//MetaDataVisitor::collect();
-		delete root_;
-		delete drivers_;
-		delete output_;
+  if ( root_ && drivers_ )
+  {
+     BasicGraphicsObject* object = root_->close();
+     if ( object )
+     {
+        /***   Start clean-up  ***/
+        drivers_->dispatch(object);
+//        if ( root_ && drivers_)
+//        {
+           //root_->execute();
+           drivers_->closeDrivers();
+           //MetaDataVisitor::collect();
+           delete root_;
+           delete drivers_;
+           delete output_;
 
-		drivers_ = 0;
-		root_ = 0;
-		output_ = 0;
-	}
+           drivers_ = 0;
+           root_    = 0;
+           output_  = 0;
+//         }
+     }
+     else MagLog::info() << "FortranMagics::pclose() > no object defined." <<endl;
+  }
+  else MagLog::info() << "FortranMagics::pclose() > no root or drivers defined." <<endl;
 
+  /*! We reset all the parameters to their default,
+      then a consecutive call to popen will not be affected by the current values.
+  */
+  ParameterManager::reset();
 
-	// the Magics log messages are not broadcast until the next log event - therefore, the
-	// last log message will not be broadcast. We fix that by flushing the message streams
-	// - we only need to do one of them, and all will be flushed behind the scenes.
-	MagLog::info().flush();
-
-	// We reset all the parameters to their default,
-	// then a consecutive call to popen will not be affected by the current values.
-	ParameterManager::reset();
-
-
-	if(getEnvVariable("MAGPLUS_QUIET").empty() )
-	{
-	/*
-		MagLog::userInfo() << "------------------------------------------------------------------\n";
-		MagLog::userInfo() << " Output files generated:\n";
-		stringarray::iterator it = output_resource_list_.begin();
-		stringarray::iterator itend = output_resource_list_.end();
-		for(; it != itend; it++)
-		{
-			MagLog::userInfo() << "  - "<<(*it)<<"\n";  
-		}
-		MagLog::userInfo() << "\n";
-	*/
-		MagLog::userInfo() << "------------------------------------------------------------------\n";
-		MagLog::userInfo() << "    COMPLETED\n";
-		MagLog::userInfo() << "\n";
-		MagLog::userInfo() << "    Any problems or suggestions? Please contact us at\n";
-		MagLog::userInfo() << "                   magics@ecmwf.int\n";
-		MagLog::userInfo() << "------------------------------------------------------------------\n";
-	}
+  printFooter();
 }
 
 void FortranMagics::drivers()
@@ -350,6 +355,7 @@ void FortranMagics::pnew(const string& type)
 		   if ( empty_ ) return;
 				finish();
 				dispatch();
+		   empty_ = true;
 
 		pop();
 		actions_.push(&FortranMagics::legend);	
@@ -365,6 +371,7 @@ void FortranMagics::pnew(const string& type)
 			}
 			finish();
 			dispatch();
+			empty_ = true;
 			actions_.push(&FortranMagics::legend);
 		    actions_.push(&FortranMagics::subpage);	
 		    actions_.push(&FortranMagics::page);	
@@ -375,7 +382,6 @@ void FortranMagics::pnew(const string& type)
 	axisContainer_ = 0;
 	geoaction_ = 0;
 	xyaction_ = 0;
-	empty_ = true;
 
 	string legend;
 	ParameterManager::get("legend", legend);
