@@ -38,6 +38,7 @@
 #include "Dimension.h"
 #include "MagicsFormat.h"
 #include "AnimationRules.h"
+#include "LegendMethod.h"
 
 using namespace magics;
 
@@ -280,9 +281,8 @@ void LegendVisitor::grid(vector<pair<float, float> >& positions)
 	if (magCompare(direction_, "column") ){
 		int row = 1;
 		int column = 1;
-		int rows = 0;
+		int rows = count/columns_;
 		// calclate the number of rows we need! 
-		rows= (count/columns_) + 1;
 		for (unsigned int i = 0; i < count; i++ ) {	
 			MagLog::debug() << "add position [" <<  column << ", " << row << "]" << endl;		 			 
 			positions.push_back(make_pair(column, row));
@@ -292,7 +292,9 @@ void LegendVisitor::grid(vector<pair<float, float> >& positions)
 				column+=2;
 			 }
 		}
-		legend_->setCoordinates(  -0.2, columns_*2,  0.5, rows);
+		legend_->setCoordinates(  -0.1, columns_*2,  0.5, rows+0.7);
+		if ( magCompare(entry_orientation_, "top_bottom") )
+			legend_->setCoordinates(  -0.1, columns_*2,  rows+0.5, 0.7);
 	return;
 	}
 
@@ -476,85 +478,126 @@ void LegendEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer&
 	FillShadingProperties* shading = new FillShadingProperties();    
 	box->setFillColour(colour());
 	box->setShading(shading);
-	
-	Polyline*  frame = new Polyline();
+    box->setFilled(true);
 	MagLog::debug() << "BoxEntry--->set at " << point << endl;
-	double width = 0.8;
-	double height = 0.5;
+	double width = 1;
+	double height = 0.4;
 	double x = point.x();
 	double y = point.y();
-	
-	box->push_back(PaperPoint(x, y-height));
-	box->push_back(PaperPoint(x, y+height));
-	box->push_back(PaperPoint(x+2, y+height));
-	box->push_back(PaperPoint(x+2, y-height));
+
+	if ( text_ ) {
+		Text* from = new Text();
+		from->push_back(PaperPoint(x-width, y - height - 0.25));
+		from->setVerticalAlign(MBOTTOM);
+		from->setAngle(angle_);
+		legend.push_back(from);
+		if ( userText_.empty()  || last_) {
+			ostringstream bottom;
+			bottom << MagicsFormat(format_, from_);
+			from->addText(bottom.str(), font_);
+		}
+		else
+			from->addText(userText_, font_);
+	}
+	if ( last_ ) {		
+		Text* to = new Text();
+		to->setAngle(angle_);
+		to->setVerticalAlign(MBOTTOM);
+		to->push_back(PaperPoint(x+width, y - height- 0.25));
+		legend.push_back(to);
+		if ( userText_.empty()  ) {
+			ostringstream top, bottom;
+			top << MagicsFormat(format_, to_);
+			to->addText(top.str(), font_);
+		}
+		else
+			to->addText(userText_, font_);
+	}
+
+
 	box->push_back(PaperPoint(x-width, y-height));
-	box->setColour(Colour("black"));
-	frame->setColour(Colour("black"));
-	frame->push_back(PaperPoint(x-width, y-height));
-	frame->push_back(PaperPoint(x-width, y+height));
-	frame->push_back(PaperPoint(x+2, y+height));
-	frame->push_back(PaperPoint(x+2, y-height));
-	frame->push_back(PaperPoint(x-width, y-height));
+	box->push_back(PaperPoint(x-width, y+height+height));
+	box->push_back(PaperPoint(x+width, y+height+height));
+	box->push_back(PaperPoint(x+width, y-height));
+	box->push_back(PaperPoint(x-width, y-height));
+	// Small check 
+	Colour colour = ( borderColour_.automatic() ) ? box->getFillColour() : borderColour_;
+
+	if ( box->getFillColour() == Colour("none") ) {
+		box->setFilled(false);
+		colour = Colour("black");
+	}
+	box->setColour(colour);
 
 
-	legend.push_back(frame);
+	legend.push_back(box);
 }
 
 
 void LegendEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer& legend)
 {
 	Polyline*  box = new Polyline();
-	Colour col = colour();
-	if ( col == "none") {
+	
+	
 		FillShadingProperties* shading = new FillShadingProperties();    
 		box->setFillColour(colour());
-
 		box->setShading(shading);
-	}
-	Polyline*  frame = new Polyline();
-
+        box->setFilled(true);
 	
-	double x = point.x();
-	double y = point.y();
-	double width = 0.4;
+    
+	MagLog::debug() << "BoxEntry--->set at " << point << endl;
+	double width = computeWidth(0.8)/2;
 	double height = 0.5;
-	
+	PaperPoint p = centreSymbolBox(point);
+	double x = p.x();
+	double y = p.y();
+	PaperPoint pt = leftTextBox(point);
+
+	if ( text_ ) {
+		Text* from = new Text();
+		from->setJustification(MLEFT);
+		from->setVerticalAlign(MHALF);
+		if ( userText_.empty()  || last_) {
+			ostringstream bottom;
+			bottom << MagicsFormat(format_, from_);
+			from->addText(bottom.str(), font_);
+		}
+		else
+			from->addText(userText_, font_);
+		PaperPoint pfrom(pt);
+		pfrom.y_ = y - height;
+		from->push_back(pfrom);
+		from->setAngle(angle_);
+		legend.push_back(from);
+	}
+	if ( last_ ) {
+		Text* to = new Text();
+		to->setVerticalAlign(MHALF);
+		to->setJustification(MLEFT);
+		to->setAngle(angle_);
+		if ( userText_.empty()  ) {
+			ostringstream top, bottom;
+			top << MagicsFormat(format_, to_);
+			to->addText(top.str(), font_);
+		}
+		else
+			to->addText(userText_, font_);
+		PaperPoint pto(pt);
+		pto.y_ =  y + height;
+		to->push_back(pto);
+		legend.push_back(to);
+	}
 	box->push_back(PaperPoint(x-width, y-height));
 	box->push_back(PaperPoint(x-width, y+height));
-	box->push_back(PaperPoint(x, y+height));
-	box->push_back(PaperPoint(x, y-height));
+	box->push_back(PaperPoint(x+width, y+height));
+	box->push_back(PaperPoint(x+width, y-height));
 	box->push_back(PaperPoint(x-width, y-height));
-	box->setColour(Colour("black"));
-	frame->setColour(Colour("black"));
-	frame->push_back(PaperPoint(x-width, y-height));
-	frame->push_back(PaperPoint(x-width, y+height));
-	frame->push_back(PaperPoint(x, y+height));
-	frame->push_back(PaperPoint(x, y-height));
-	frame->push_back(PaperPoint(x-width, y-height));
-	
-	
-	legend.push_back(frame);
-
-	ostringstream top, bottom;
-	top << MagicsFormat(format_, from_); 
-	bottom << MagicsFormat(format_,  to_); 
-
-
-	Text* from = new Text();
-	Text* to = new Text();
-	from->setVerticalAlign(MHALF);
-
-	to->setVerticalAlign(MHALF);		
-	from->addText(top.str(), font_);
-
-	to->addText(bottom.str(), font_);
-
-	to->push_back(PaperPoint(x+0.25, y + height));
-	from->push_back(PaperPoint(x+0.25, y - height));
-
-	legend.push_back(from);
-	legend.push_back(to);
+	Colour colour = ( borderColour_.automatic() ) ? box->getFillColour() : borderColour_;
+	if ( box->getFillColour() == Colour("none") ) {
+		box->setFilled(false);
+	}
+	box->setColour(colour);
+	legend.push_back(box);
 }
 
 void EmptyEntry::rowBox(const PaperPoint&, BasicGraphicsObjectContainer&)
@@ -655,6 +698,11 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 
 	double x = point.x();
 	double y = point.y();
+	vector<Polyline*> ticks;
+
+	Colour grid_colour = histogram_->getHisto_grid_colour();
+	int grid_thickness = histogram_->getHisto_grid_thickness();
+	LineStyle grid_style = histogram_->getHisto_grid_style();
 
 	if ( text_ ) {
 			Text* from = new Text();
@@ -669,6 +717,12 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 			}
 			else
 				from->addText(userText_, font_);
+			Polyline* tick = new Polyline();
+            tick->setLineStyle(M_SOLID);
+			tick->setColour(Colour("black"));
+			tick->push_back(PaperPoint(x-width, y + 1.1));
+			tick->push_back(PaperPoint(x-width,  y + 0.85));
+			ticks.push_back(tick);
 		}
 		if ( last_ ) {
 			Text* to = new Text();
@@ -685,11 +739,18 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 				to->addText(userText_, font_);
 
 			Polyline* axe = new Polyline();
-            axe->setLineStyle(M_DASH);
-			axe->setColour(Colour("black"));
+			axe->setColour(grid_colour);
+			axe->setThickness(grid_thickness);
+			axe->setLineStyle(grid_style);
 			axe->push_back(PaperPoint(x+width, y -0.8));
 			axe->push_back(PaperPoint(x+width,  y + 0.8));
 			legend.push_back(axe);
+			Polyline* tick = new Polyline();
+			tick->setLineStyle(M_SOLID);
+			tick->setColour(Colour("black"));
+			tick->push_back(PaperPoint(x+width, y + 1.1));
+			tick->push_back(PaperPoint(x+width,  y + 0.85));
+			ticks.push_back(tick);
 		}
 	if ( first_ ) {
 		Text* to = new Text();
@@ -698,7 +759,7 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 		to->setJustification(MRIGHT);
 		to->push_back(PaperPoint(x-width, y - 0.8 ));
 		legend.push_back(to);
-		if ( userText_.empty()  ) {
+		if ( userText_.empty() && histogram_->getHisto_max() ) {
 			ostringstream top, bottom;
 			top << MagicsFormat(format_, totalPopulation_);
 			to->addText(top.str(), font_);
@@ -706,7 +767,9 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 		else
 			to->addText(userText_, font_);
 		Polyline* axe = new Polyline();
-		axe->setColour(Colour("black"));
+		axe->setColour(grid_colour);
+		axe->setThickness(grid_thickness);
+		axe->setLineStyle(grid_style);
 		axe->push_back(PaperPoint(x-width, y -0.8));
 		axe->push_back(PaperPoint(x-width,  y + 0.8));
         
@@ -727,34 +790,70 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 	if ( border == Colour("none") ) {
 		box_->setFilled(false);
 	}
-	box_->setColour(border);
-    Colour black("black");
-    Polyline* box = box_->getNew();	
-    box->push_back(PaperPoint(x-width, y + 1.1));
-	box->push_back(PaperPoint(x-width, y + 0.85));
-	box->push_back(PaperPoint(x+width, y + 0.85));
-	box->push_back(PaperPoint(x+width, y + 1.1));
-	box->push_back(PaperPoint(x-width, y + 1.1));
-    box->setColour(black);
-    legend.push_back(box);
 
+	box_->setColour(border);
 	legend.push_back(box_);
+	Polyline* box =  box_->getNew();
+	box->setColour(border);
+	box->push_back(PaperPoint(x-width, y + 1.1));
+	box->push_back(PaperPoint(x+width, y + 1.1));
+	box->push_back(PaperPoint(x+width, y + 0.85));
+	box->push_back(PaperPoint(x-width, y + 0.85));
+	box->push_back(PaperPoint(x-width, y + 1.1));
+	legend.push_back(box);
+
+    Polyline* topbox = box_->getNew();
+    topbox->setColour(grid_colour);
+    topbox->setThickness(grid_thickness);
+    topbox->setLineStyle(grid_style);
+    topbox->push_back(PaperPoint(x-width, y + 1.1));
+    topbox->push_back(PaperPoint(x+width, y + 1.1));
+	legend.push_last(topbox);
+
+	Polyline* bottombox = box_->getNew();
+	bottombox->setColour(grid_colour);
+	bottombox->setThickness(grid_thickness);
+	bottombox->setLineStyle(grid_style);
+	bottombox->push_back(PaperPoint(x-width, y + 0.85));
+	bottombox->push_back(PaperPoint(x+width, y + 0.85));
+	legend.push_last(bottombox);
+
+
     
     Polyline* topline = new Polyline();
-	topline->setColour(black);
+	topline->setColour(box_->getFillColour());
     topline->setLineStyle(M_DASH);
 	topline->push_back(PaperPoint(x-width, y -0.8));
 	topline->push_back(PaperPoint(x+width,  y - 0.8));
 	
-    legend.push_back(topline);
+    legend.push_last(topline);
     
     Polyline* bottomline = new Polyline();
-	bottomline->setColour(black);
-    bottomline->setThickness(2);
+    bottomline->setColour(grid_colour);
+    bottomline->setThickness(grid_thickness);
+    bottomline->setLineStyle(grid_style);
+
     
 	bottomline->push_back(PaperPoint(x-width, y + 0.8));
 	bottomline->push_back(PaperPoint(x+width,  y + 0.8));
-    legend.push_back(bottomline);
+    legend.push_last(bottomline);
+
+    for (vector<Polyline*>::iterator tick = ticks.begin(); tick != ticks.end(); ++tick)
+    	legend.push_back(*tick);
+
+    if ( histogram_->getHisto_mean() && meanSet_ ) {
+    	Symbol* symbol = new Symbol();
+
+    	symbol->setColour(histogram_->getHisto_mean_colour());
+    	ostringstream m;
+    	m << "magics_" << histogram_->getHisto_mean_marker();
+    	symbol->setSymbol(m.str());
+    	symbol->setHeight(histogram_->getHisto_mean_size());
+    	double pos = ((2*width)/(to_-from_)) * (meanValue_ - from_) + (x - width);
+    	symbol->push_back(PaperPoint(pos,  y + 1.));
+    	legend.push_last(symbol);
+
+    }
 }
 void BoxEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer& legend)
 {
