@@ -314,6 +314,26 @@ public :
 	}
 };
 
+/*! \brief Converts WIND_ARROW_LEGEND into LEGEND
+
+  The convention to enable Legends for Wind in Magics++ has changed.
+*/
+class CoastlinesResolution: public CompatibilityHelper {
+public :
+	CoastlinesResolution() : CompatibilityHelper("map_coastline_resolution")  { }
+	~CoastlinesResolution() {}
+	bool operator()(const string& res)
+	{
+		if ( magCompare(res, "high") || magCompare(res, "medium") ) {
+		MagLog::warning() << "From2.14: Magics is using a new dataset for coastlines naturalearth.\n"
+		            << "             You can experience longer processing time and bigger output files \n"
+					<< "             if you use medium or high on a large area.\n"
+					<< "             if so, you may want to come back to low or automatic resolution.\n";
+		}
+		return false;
+	}
+};
+
 
 /*! \brief Converts ps_file_name into output_file_root_name.
 
@@ -1575,3 +1595,4 @@ public :
 	}
 };
 static PageIDWarning page_id_line_logo_plot;
+static CoastlinesResolution map_coastline_resolution;
