@@ -129,6 +129,7 @@ public :
                 	coordinates.push_back(make_pair(make_pair(y2, x1), make_pair(r2, c1)));
                 	coordinates.push_back(make_pair(make_pair(y2, x2), make_pair(r2, c2)));
                 }
+
                 for (vector< pair<pair<double, double>, pair<int, int> > >::iterator coord = coordinates.begin(); coord != coordinates.end(); ++coord) {
                 	double distance = (row- coord->first.first)*(row-coord->first.first) + (column - coord->first.second)*(column - coord->first.second);
                 	//cout << distance << " [ " << coord->first.first << ", " << coord->first.second << "]" << endl;
@@ -136,13 +137,17 @@ public :
                 	helper.insert(make_pair(distance, *coord));
                 }
 
+				if ( distances.empty() ) 
+                    return matrix_.missing();
 
-               // cout << "min value->" << *std::min_element(distances.begin(), distances.end()) << endl;
-                pair<pair<double, double>, pair<int, int> >  nearest = coordinates[*std::min_element(distances.begin(), distances.end())];
-               // cout << "found [ " << nearest.first.first << ", " << nearest.first.second << "]->[";
-               // cout << nearest.second.first << ", " << nearest.second.second << "]" << endl;
-                return (*this)(nearest.second.first, nearest.second.second);
+				double min = *std::min_element(distances.begin(), distances.end());
 
+                map<double, pair<pair<double, double>,  pair<int, int> > >::iterator near = helper.find(min);
+
+				if ( near == helper.end() ) 
+					return  matrix_.missing();
+
+				return (*this)(near->second.second.first, near->second.second.second);
 
     }
 	
