@@ -848,15 +848,10 @@ void PolarStereographicProjection::coastSetting(map<string, string>& setting, do
 	setting["lakes"]      = resol + "/" + resol + "_lakes";
 	setting["land"]       = resol + "/" + resol + "_land";
 	setting["rivers"]     = resol + "/" + resol + "_rivers_lake_centerlines";
-	if(!magCompare(resol,"110m"))
-	{
-		setting["boundaries"] = "50m/50m_admin_0_boundary_lines_land";
-		setting["administrative_boundaries"] = "10m/10m_admin_1_states_provinces_shp";
-	}
-	else{
-		setting["boundaries"] = "110m/110m_admin_0_boundary_lines_land";
-		setting["administrative_boundaries"] = "110m/110m_admin_1_states_provinces_shp";
-	}
+	setting["boundaries"] = resol + "/" + resol + "_admin_0_boundary_lines_land";
+	
+	//! \note Administraive borders hardcoded to 10m resolution (low res version do not contain all info)
+	setting["administrative_boundaries"] = "10m/10m_admin_1_states_provinces_shp";
 
 	MagLog::dev() << "GeoRectangularProjection::coastSetting[" << abswidth << ", " << absheight << "]->" <<  ratio << " resol: "<<resol<< endl;
 }
