@@ -34,7 +34,6 @@
 #include "LocalTable.h"
 #include "DateTime.h"
 #include "GribTables.h"
-#include <locale>
 #include "GribInterpretor.h"
 #include "XmlReader.h"
 #include "TextVisitor.h"
@@ -606,22 +605,9 @@ public:
 		Date part1 = Date(day);
 		magics::Time part2 = magics::Time(hour, mn, 0);
 		DateTime full(part1, part2);
-		tm convert = full;
-		try {
-			locale loc("");
-			ostringstream out;
-			out.imbue(loc);   
-			const std::time_put<char>& tfac = use_facet<time_put<char> >(loc); 
-			tfac.put(out, out, ' ', &convert, format.c_str(), format.c_str()+format.length());       
-			return out.str();
-		}
-		catch (...)
-		{
-			MagLog::error() << "Problem to setup the locale\n"
-			             << "Check you LOCALE variable-->current value : " << getEnvVariable("LANG")<<endl;
-			MagLog::broadcast();
-			assert(false);
-		}
+	    
+		return full.tostring(format);
+		
 	}
 
 	string startDate(const XmlNode& node)
@@ -638,21 +624,8 @@ public:
 			magics::Time part2 = magics::Time(hour, mn, 0);
 			DateTime full(part1, part2);	
 			full = full + (step*3600);
-			tm convert = full;
-			try {
-				locale loc("");
-				ostringstream out;
-				out.imbue(loc);   
-				const std::time_put<char>& tfac = use_facet<time_put<char> >(loc); 
-				tfac.put(out, out, ' ', &convert, format.c_str(), format.c_str()+format.length());       
-				return out.str();
-			}
-			catch (...)
-			{
-				MagLog::error() << "Problem to setup the locale" << endl;
-				MagLog::error() << "Check you LOCALE variable-->current value : " <<  getEnvVariable("LANG")<< endl;
-				assert(false);
-			}
+			    
+			return full.tostring(format);
 	}
 
 	string validDate(const XmlNode& node)
@@ -669,22 +642,9 @@ public:
 			Date part1 = Date(day);
 			magics::Time part2 = magics::Time(hour, mn, 0);
 			DateTime full(part1, part2);	
-			 full = full + (step*3600);
-			tm convert = full;
-			try {
-				locale loc("");
-				ostringstream out;
-				out.imbue(loc);   
-				const std::time_put<char>& tfac = use_facet<time_put<char> >(loc); 
-				tfac.put(out, out, ' ', &convert, format.c_str(), format.c_str()+format.length());       
-				return out.str();
-			}
-			catch (...)
-			{
-				MagLog::error() << "Problem to setup the locale" << endl;
-				MagLog::error() << "Check you LOCALE variable-->current value : " <<  getEnvVariable("LANG")<< endl;
-				assert(false);
-			}
+			      
+			return full.tostring(format);
+			
 	}
 
 	string endDate(const XmlNode& node)
@@ -700,22 +660,10 @@ public:
 		Date part1 = Date(day);
 		magics::Time part2 = magics::Time(hour, mn, 0);
 		DateTime full(part1, part2);	
-		 full = full + ( step*3600 );
-		tm convert = full;
-		try {
-			locale loc("");
-			ostringstream out;
-			out.imbue(loc);   
-			const std::time_put<char>& tfac = use_facet<time_put<char> >(loc); 
-			tfac.put(out, out, ' ', &convert, format.c_str(), format.c_str()+format.length());       
-			return out.str();
-		}
-		catch (...)
-		{
-			MagLog::error() << "Problem to setup the locale" << endl;
-			MagLog::error() << "Check you LOCALE variable-->current value : " <<  getEnvVariable("LANG")<< endl;
-			assert(false);
-		}
+		full = full + ( step*3600 );
+		    
+		return full.tostring(format);
+		
 	}
 
 	void visit(const XmlNode& node)
@@ -927,7 +875,7 @@ void GribDecoder::visit(MetaDataCollector& step)
 		  	if(information_.find(key->first) == information_.end())
 			{  
 				//Compute stats
-				if (step.attribute(key->first).group() == MetaDataAttribute::StatsGroup)
+				if (step.attribute(key->first).group() == MetaDataAttribute::StatsGroup && matrix_ )
 				{
 					stats_.clear();
 					
@@ -962,6 +910,35 @@ void GribDecoder::visit(MetaDataCollector& step)
 					}
 
 				}
+				else if(key->first == "scaling_formula" ||key->first == "scaled_units" )
+				{
+					double scaling, offset;
+					string oriUnits, derivedUnits;
+					string representation = getString("typeOfGrid");
+					try 
+					{
+						auto_ptr<GribInterpretor> interpretor(SimpleObjectMaker<GribInterpretor>::create(representation));    	
+						interpretor->scaling(*this, scaling, offset,oriUnits,derivedUnits);
+						if(scaling==1 && offset == 0)
+						{
+							information_["scaling_formula"]="";
+							information_["scaled_units"]="";
+						}
+						else
+						{  
+							string offsetSign=(offset >=0)?"+":"-";
+							information_["scaling_formula"]="(value * " + tostring(scaling) + ") " + offsetSign + " " + tostring(fabs(offset));
+							information_["scaled_units"]= derivedUnits;
+						}
+					}	
+					catch (NoFactoryException&)
+					{
+						MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<<endl;;
+						information_[key->first]="N/A";
+					}
+					
+				}       	
+				
 			}	
 			//If key is found in information_ we copy it
 			else
@@ -1337,21 +1314,6 @@ public:
 	}
 };
 
-static locale& getLocale()
-{
-	static locale loc= locale::classic();
-	try {
-		loc = locale("");
-	}
-	catch (...)
-	{
-		MagLog::error() << "Problem to setup the locale" << endl;
-		MagLog::error() << "Check you LANG variable-->current value : " <<  getEnvVariable("LANG")<<endl;
-	
-		loc= locale::classic();
-	}
-	return loc;
-}
 
 
 class GribBaseDateHandler : public TitleFieldHandler<GribDecoder>
@@ -1370,15 +1332,10 @@ public:
 		Date part1 = Date(date);
 		Time part2 = Time(hour, mn, 0);
 		DateTime full(part1, part2);
-		tm convert = full;
-
-		out.imbue(getLocale());   
-		const std::time_put<char>& tfac = use_facet<time_put<char> >(getLocale()); 
-		string format = field.attribute("format", "%A %d %B %Y at %H UTC");
-		tfac.put(out, out, ' ', &convert, format.c_str(), format.c_str()+format.length());        
 	
-		MagLog::dev() << "title--> " << out.str() << endl;
-		title.back() += out.str();
+		string format = field.attribute("format", "%A %d %B %Y at %H UTC");
+	
+		title.back() += full.tostring(format);
 	}	
 };
 
@@ -1389,7 +1346,7 @@ public:
     ~GribValidDateHandler() {}
     void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib)
     {
-	ostringstream out;
+	    ostringstream out;
         long date = grib.getLong("date");    
         long hour = grib.getLong("hour");  
         long mn   = grib.getLong("minute"); 
@@ -1400,22 +1357,11 @@ public:
         DateTime full(part1, part2);
         full = full + step;
 
-        tm convert = full;
-        try {
-	        locale loc("");
-	        out.imbue(loc);
-
-	        const time_put<char>& tfac = use_facet<time_put<char> >(loc); 
-	        string format = field.attribute("format", "%A %d %B %Y %H UTC");
-	        tfac.put(out, out, ' ', &convert, format.c_str(), format.c_str()+format.length());        
-	        title.back() += out.str();
-        }
-    	catch (...)
-    	{
-    		MagLog::error() << "Problem to setup the locale" << endl;
-    		MagLog::error() << "Check you LOCALE variable-->current value : " <<  getEnvVariable("LANG")<<endl;;
-    		assert(false);
-    	}
+        
+	    string format = field.attribute("format", "%A %d %B %Y %H UTC");
+	        
+	    title.back() += full.tostring(format);
+       
 
     }
 };
