@@ -573,17 +573,10 @@ void GribReducedGaussianInterpretor::interpretAsMatrix(const GribDecoder& grib,
 
 	size_t aux = 2*res;
 	grib_get_double_array(grib.id(),"pl",pl,&aux);
-	// We have to determine if the field is global! 
-	bool global = same(north-south, 180.);
-	if (global) {
-		MagLog::dev() << "YES THE FIELD IS GLOBAL" << endl;
-		 // We have to determine if the field is global!
-		bool global = same(north-south, 180.);
-		if (global)
-		{
-        		MagLog::dev() << "YES THE FIELD IS GLOBAL" << endl;
-        		east = west + 360;
-		}
+	
+    // We have to determine if the field is global! 
+	if (north-south > 175.) {
+        east = west + 360.;
 	}
 
 	// compute the number of points we'll be adding to the matrix so that we can
