@@ -192,8 +192,9 @@ static void XMLCALL character (void *userData,
 
 BufrIdentifiers::BufrIdentifiers(int centre) : centre_(centre) 
 {
-	ostringstream file;
+	ostringstream file, deffile;
 	file << getEnvVariable("MAGPLUS_HOME") <<  MAGPLUS_PATH_TO_SHARE_ << "bufr_" << centre << ".xml";
+	deffile << getEnvVariable("MAGPLUS_HOME") <<  MAGPLUS_PATH_TO_SHARE_ << "bufr_98.xml";
 	char buf[BUFSIZ];
 	XML_Parser parser = XML_ParserCreate(NULL);
 	int done;
@@ -201,7 +202,12 @@ BufrIdentifiers::BufrIdentifiers(int centre) : centre_(centre)
 	XML_SetElementHandler(parser, startElement, endElement);
 
 	FILE* in  = fopen(file.str().c_str(), "r");
-	if (!in) return;
+	if (!in) {
+		// Open the default template for 98! 
+		//and send a big warning! 
+	    in  = fopen(deffile.str().c_str(), "r");
+	    MagLog::warning() << "No definition file for [" << centre << "]: We use ECMWF definitions " <<  endl;
+	}
 
 	do
 	{
@@ -388,6 +394,7 @@ public:
 		   val = family.getType(type.first, type.second);		
 		   if (val == "")
 		   {
+
 		      MagLog::warning() << "BufrTypeAccessor> No template type for [" << centre << ", " << type.first << ", " << type.second << "][centre, type, subtype]" << endl;
 		      val = "position";
 		   }
@@ -700,6 +707,7 @@ void ObsDecoder::customisedPoints(const Transformation& transformation, const st
 			   PaperPoint point = transformation(geo);
 			   if ( transformation.in(point) ) {
 				   CustomisedPoint* point = new CustomisedPoint(loc.x(), loc.y(),  obs.findSomeIdent());		
+				   point->type(type);
 				
 				   for (VectorOfPointers<vector<BufrAccessor*> >::const_iterator accessor = accessors.begin(); accessor != accessors.end(); ++accessor)
 				   {
