@@ -231,15 +231,15 @@ void KMLDriver::close()
 			{
 				err = zipCloseFileInZip(zf);
 				if (err!=ZIP_OK)
-					printf("error in closing xxxx in the zipfile\n");
+					MagLog::error() << "Could NOT close KMZ file "<< fileName_<< endl;
 			}
-//				delete [] filename;
+//			delete [] filename;
 		}
 		free(buf);
 
 		err = zipClose(zf,0);
 		if (err != ZIP_OK)
-			printf("error in closing %s\n",fileName_.c_str());
+			MagLog::error() << "Could NOT close KMZ file "<< fileName_<< endl;
 		else if (!getDebug())
 		{
 			stringarray::iterator it = kml_output_resource_list_.begin();
@@ -320,7 +320,7 @@ MAGICS_NO_EXPORT void KMLDriver::project(const magics::Layout& layout) const
 */
 MAGICS_NO_EXPORT void KMLDriver::redisplay(const StaticLayer& layer) const
 {
-cout <<"KML staticlayer > "<<layer.name() <<" - "<<layer.kmlTimeBegin()<<endl;
+//cout <<"KML staticlayer > "<<layer.name() <<" - "<<layer.kmlTimeBegin()<<endl;
   if(!magCompare("coastlines",layer.name()) || getCoastlines() )
   {
 //	if(!magCompare(currentLayer_,layer.name()))
@@ -340,7 +340,7 @@ cout <<"KML staticlayer > "<<layer.name() <<" - "<<layer.kmlTimeBegin()<<endl;
 
 MAGICS_NO_EXPORT void KMLDriver::redisplay(const StepLayer& layer) const
 {
-  cout <<"KML StepLayer> "<<layer.name() <<" - "<<layer.kmlTimeBegin()<<endl;
+//  cout <<"KML StepLayer> "<<layer.name() <<" - "<<layer.kmlTimeBegin()<<endl;
   if(!magCompare("coastlines",layer.name()) || getCoastlines() )
   {
 //	if(!magCompare(currentLayer_,layer.name()))
@@ -365,7 +365,7 @@ MAGICS_NO_EXPORT void KMLDriver::redisplay(const StepLayer& layer) const
  */
 MAGICS_NO_EXPORT void KMLDriver::redisplay(const NoDataLayer& layer) const
 {
-   cout << "KML::NoDataLayer> "<<layer.name()<< endl;
+//   cout << "KML::NoDataLayer> "<<layer.name()<< endl;
 }
 
 /*!
@@ -374,7 +374,7 @@ MAGICS_NO_EXPORT void KMLDriver::redisplay(const NoDataLayer& layer) const
 */
 MAGICS_NO_EXPORT void KMLDriver::newLayer() const
 {
-cout << "KML::newLayer()> "<<currentLayer_<< endl;
+//cout << "KML::newLayer()> "<<currentLayer_<< endl;
 	if (kml_placemark_) closePlacemark();
 
 	debugOutput("Start Layer - "+currentLayer_);
@@ -397,7 +397,7 @@ cout << "KML::newLayer()> "<<currentLayer_<< endl;
 */
 MAGICS_NO_EXPORT void KMLDriver::closeLayer() const
 {
-  cout << "KML::closeLayer()> "<<currentLayer_<< endl;
+//  cout << "KML::closeLayer()> "<<currentLayer_<< endl;
 	if (kml_placemark_) closePlacemark();
 
 	layer_=false;
