@@ -1100,7 +1100,7 @@ MAGICS_NO_EXPORT void PostScriptDriver::renderText(const Text& text) const
 
 			if(u>1)
 			{
-				*ps <<"gs "<< x0 << " " << y0 << " t ("<< tmp.str() << ") stringwidth pop HA mul VA Height mul moveto "
+				*ps <<"gs "<< x0 << " " << y0 << " t ("<< all_text.str() << ") stringwidth pop HA mul VA Height mul moveto "
 				    << "("<<tmp.str()<< ") "<<showCommand<<"\n";
 			}
 			else
