@@ -217,7 +217,6 @@ void CoastPlotting::operator()(DrawingVisitor& parent)
   lake_.clear();
 
   coastSet_["administrative_boundaries"] = "10m/10m_admin_1_states_provinces_shp";
-  coastSet_["boundaries"] = "50m/50m_admin_0_boundary_lines_land";
 
   if ( magCompare(CoastPlottingAttributes::resolution_, "full") ) {
         string resol = "10m";
@@ -225,7 +224,7 @@ void CoastPlotting::operator()(DrawingVisitor& parent)
         coastSet_["lakes"]      = resol + "_full/" + resol + "_lakes";
         coastSet_["land"]       = resol + "_full/" + resol + "_land";
         coastSet_["rivers"]     = resol + "_full/" + resol + "_rivers_lake_centerlines";
-//        coastSet_["boundaries"] = resol + "/" + resol + "_admin_0_boundary_lines_land";
+        coastSet_["boundaries"] = resol + "/" + resol + "_admin_0_boundary_lines_land";
   }
   else if ( magCompare(CoastPlottingAttributes::resolution_, "high") ) {
         string resol = "10m";
@@ -233,7 +232,7 @@ void CoastPlotting::operator()(DrawingVisitor& parent)
         coastSet_["lakes"]      = resol + "/" + resol + "_lakes";
         coastSet_["land"]       = resol + "/" + resol + "_land";
         coastSet_["rivers"]     = resol + "/" + resol + "_rivers_lake_centerlines";
-//        coastSet_["boundaries"] = resol + "/" + resol + "_admin_0_boundary_lines_land";
+        coastSet_["boundaries"] = resol + "/" + resol + "_admin_0_boundary_lines_land";
   }
   else if ( magCompare(CoastPlottingAttributes::resolution_, "medium") ) {
         string resol = "50m";
