@@ -415,7 +415,14 @@ public:
 	}
 	virtual int coef(int i, double val) const {
 		double height = this->parent_.value(this->indexes_[i])-val;		
-		return ( height ) ? (height/abs(height))+1 : 1;		
+		int c = ( height ) ? (height/abs(height))+1 : 1;
+        // Make sure we always return a posibble index!
+		if ( c < 0 || c > 2 ) {
+			MagLog::debug() << "c<0" << c << " -> " << height << endl;
+			c = 0;
+		}
+		
+		return c;
 	}
 
 	virtual bool isMissing(int i) const {
